package Tapper::Schema;
BEGIN {
  $Tapper::Schema::AUTHORITY = 'cpan:AMD';
}
{
  $Tapper::Schema::VERSION = '4.0.2';
}
# ABSTRACT: Tapper - Database schemas for Tapper

use warnings;
use strict;

1; # End of Tapper::Schema

__END__
=pod

=encoding utf-8

=head1 NAME

Tapper::Schema - Tapper - Database schemas for Tapper

=head1 AUTHOR

AMD OSRC Tapper Team <tapper@amd64.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..

This is free software, licensed under:

  The (two-clause) FreeBSD License

=cut

